==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/siconv.sql <==
set @@character_set_client = 'utf8';

delimiter //
DROP FUNCTION IF EXISTS siconv//
create function siconv(uw varchar(200)) returns double
  deterministic
  sql security invoker
  begin
    declare w, fv, ov double;
    declare e varchar(100);
    declare i integer;

    set i = instr(uw, ' ');
    if i = 0
     then
      return 0;
    else
      set w = left(uw, i-1) + 0.0;
      set e = substr(uw, i+1);
      select sifaktor, sioffset into fv, ov
        from einheiten where bname = e and sifaktor > 0;

      if fv is NULL OR ov is NULL
       then
        return 0;
      else
        return w*fv+ov;
      end if;
    end if;
  end//

GRANT EXECUTE on FUNCTION siconv
  to logginglesen@'localhost', loggingtest@'localhost', 'loggingadmin'@'localhost'//


DROP FUNCTION IF EXISTS csiconv//
create function csiconv(uw varchar(200)) returns double
  deterministic
  sql security invoker
  begin
    declare w, fv, ov double;
    declare e varchar(100);
    declare i integer;

    set i = instr(uw, ' ');
    if i = 0
     then
      return 0;
    else
      set w = left(uw, i-1) + 0.0;
      set e = substr(uw, i+1);
      select sifaktor, sioffset into fv, ov
        from einheiten
        where sifaktor > 0
          and (name = e OR concat(bname, '/h') = e OR concat(bname, '/h²') = e)
        order by name != e, concat(bname, '/h') != e
        limit 1;

      if fv is NULL OR ov is NULL
       then
        return 0;
      else
        return w*fv+ov;
      end if;
    end if;
  end//

GRANT EXECUTE on FUNCTION csiconv
  to logginglesen@'localhost', loggingtest@'localhost', 'loggingadmin'@'localhost'//

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/siconv.sql <==
-- siconv.sql
--
-- function siconv(uw) returns double
-- uw: value, format: '<n> <unit>'
-- return: value in SI unit

-- function csiconv(uw) returns double
-- uw: value, format: '<n> <unit>'
-- return: value in SI unit
-- csiconv is for compressed values (<unit>/h or <unit>/h²)

set @@character_set_client = 'utf8';

delimiter //
DROP FUNCTION IF EXISTS siconv//
create function siconv(uw varchar(200)) returns double
  deterministic
  sql security invoker
  begin
    declare w, fv, ov double;
    declare e varchar(100);
    declare i integer;

    select instr(uw, ' ') into i;
    if i = 0
     then
      return 0;
    else
      select left(uw, i-1) + 0.0 into w;
      select substr(uw, i+1) into e;
      select sifaktor, sioffset into fv, ov from einheiten where name = e and sifaktor > 0;

      if fv is NULL OR ov is NULL
       then
        return 0;
      else
        return w*fv+ov;
      end if;
    end if;
  end//

GRANT EXECUTE on FUNCTION siconv
  to logginglesen@'localhost', loggingtest@'localhost', 'loggingadmin'@'localhost'//


DROP FUNCTION IF EXISTS csiconv//
create function csiconv(uw varchar(200)) returns double
  deterministic
  sql security invoker
  begin
    declare w, fv, ov double;
    declare e varchar(100);
    declare i integer;

    set i = instr(uw, ' ');
    if i = 0
     then
      return 0;
    else
      set w = left(uw, i-1) + 0.0;
      set e = substr(uw, i+1);
      select sifaktor, sioffset into fv, ov from einheiten
        where sifaktor > 0
          and (name = e OR concat(name, '/h') = e OR concat(name, '/h²') = e)
        order by name != e, concat(name, '/h') != e
        limit 1;

      if fv is NULL OR ov is NULL
       then
        return 0;
      else
        return w*fv+ov;
      end if;
    end if;
  end//

GRANT EXECUTE on FUNCTION csiconv
  to logginglesen@'localhost', loggingtest@'localhost', 'loggingadmin'@'localhost'//
